@@ -93,6 +93,38 @@ def split_video(video_file_path, output_path=None,
         subprocess.call(command)
 
 
+def split_video_from_stamps(
+        video_file_path,
+        start_stamps, end_stamps,
+        output_paths=None,
+        output_dirpath=None,
+        filename_tmpl='video_{start_frame:05}_{end_frame:05}.mp4'):
+    if len(start_stamps) != len(end_stamps):
+        raise RuntimeError(
+            'Length not much len(start_stamps) != len(end_stamps)'
+            '({})!=({})'.format(len(start_stamps), len(end_stamps)))
+    fps = get_video_avg_frame_rate(video_file_path)
+    if output_paths is None:
+        output_paths = []
+        if output_dirpath is None:
+            tmp_output_dir = tempfile.TemporaryDirectory()
+            tmp_output_dir.cleanup()
+            os.makedirs(tmp_output_dir.name, exist_ok=True)
+            output_dirpath = tmp_output_dir.name
+        output_dirpath = Path(output_dirpath)
+        for i, (s, e) in enumerate(zip(start_stamps, end_stamps)):
+            start_frame = int(math.ceil(s * fps))
+            end_frame = int(math.ceil(e * fps))
+            output_paths.append(output_dirpath
+                                / filename_tmpl.format(
+                                    start_frame=start_frame,
+                                    end_frame=end_frame))
+    for i, (s, e, video_out) in enumerate(zip(start_stamps, end_stamps,
+                                              output_paths)):
+        split_video(video_file_path, video_out, start_time=s, end_time=e)
+    return output_paths
+
+
 def extract_target_frame_from_timestamp(video_filepath, timestamp):
     """Extract target frame from timestamp.
 
